# v0.10.0

Release date: 2025-02-04

```{include} ../early-access.md
```

## Release Notes

This release has breaking changes. It also contains new features.
We recommend all customers upgrade to this release.

### Breaking Changes

- The default value for `batch_processing` in [`Project:create_simulation()`](#luminarycloud.Project.create_simulation) has been changed to `True`.
- [`Geometry:modify()`](#luminarycloud.Geometry.modify) no longer has a return value.
- The parameter `params_json_path` has been removed from [`SimulationTemplate:update()`](#luminarycloud.SimulationTemplate.update).
- The classes [`GeometryEntity`](#luminarycloud.params.geometry.GeometryEntity), [`Volume`](#luminarycloud.params.geometry.Volume), and [`Surface`](#luminarycloud.params.geometry.Surface) are now immutable.

See the [Migration Guide](#migration-guide) for more details on how to update your code.

### Features

- API key support
  - [`luminarycloud.Client`](#luminarycloud.Client) has a new optional `api_key` parameter.
  - The default client will use the `LC_API_KEY` environment variable if it is set.
- New types [`FirstOrderAdFloat`](#luminarycloud.types.FirstOrderAdFloat) and [`SecondOrderAdFloat`](#luminarycloud.types.SecondOrderAdFloat) has been added to `luminarycloud.types`.
- New exceptions [`AuthenticationError`](#luminarycloud.exceptions.AuthenticationError), [`InvalidRequestError`](#luminarycloud.exceptions.InvalidRequestError), [`PermissionDeniedError`](#luminarycloud.exceptions.PermissionDeniedError),
  [`NotFoundError`](#luminarycloud.exceptions.NotFoundError), [`AlreadyExistsError`](#luminarycloud.exceptions.AlreadyExistsError), and [`FailedPreconditionError`](#luminarycloud.exceptions.FailedPreconditionError) have been
  added to `luminarycloud.exceptions`.
- [`create_tag()`](#luminarycloud.Geometry.create_tag) and [`list_tags()`](#luminarycloud.Geometry.list_tags) have been added to `luminarycloud.Geometry`.
- [`get_simulation_param()`](#luminarycloud.SimulationTemplate.get_simulation_param) has been added to `luminarycloud.SimulationTemplate`.
- [`EntityIdentifier`](#luminarycloud.EntityIdentifier) has been added to `luminarycloud`.
- Support for RectilinearTable parameters in simulation parameters.
  - New enum [`TableType`](#luminarycloud.enum.TableType) has been added to `luminarycloud.enum`.
  - [`create_table()`](#luminarycloud.Project.create_table) has been added to `luminarycloud.Project`.
  - [`list_tables()`](#luminarycloud.SimulationTemplate.list_tables) has been added to `luminarycloud.SimulationTemplate`.

### Deprecations

- [`create_mesh()`](#luminarycloud.Project.create_mesh) has been deprecated in favor of [`create_or_get_mesh()`](#luminarycloud.Project.create_or_get_mesh).

### Bug Fixes / Improvements

- Fixed a bug where the `min_size` and `max_size` parameters of
  [`MeshGenerationParams`](#luminarycloud.meshing.MeshGenerationParams) did not work.
- Fixed an issue where a second interactive authentication session would be
  be started when the first one failed.
- Silenced error log when silent authentication fails.
- Server errors are now raised as [`RpcError`](#luminarycloud.exceptions.RpcError) exceptions, and their tracebacks
  are simplified.

## Migration Guide

### Explicitly set the `batch_processing` parameter to `False`

The `batch_processing` parameter in [`Project:create_simulation()`](#luminarycloud.Project.create_simulation) now defaults to `True`.
If you want to disable batch processing, you must explicitly set the parameter to `False`.

### Replacing the return values of `Geometry:modify()`

[`Geometry:modify()`](#luminarycloud.Geometry.modify) used to return volumes, features, and feature issues. You
can retrieve these values separately using [`list_entities()`](#luminarycloud.Geometry.list_entities), [`list_features()`](#luminarycloud.Geometry.list_features),
and [`list_feature_issues()`](#luminarycloud.Geometry.list_feature_issues).

If you had code that looked like this:

```python
volumes, features, feature_issues = geometry.modify(...)
```

You should now update it to look like this:

```python
geometry.modify(...)
volumes, _ = geometry.list_entities()
features = geometry.list_features()
feature_issues = geometry.list_feature_issues()
```

Note: the volumes returned by [`list_entities()`](#luminarycloud.Geometry.list_entities) are now [`Volume`](#luminarycloud.params.geometry.Volume) objects instead
of protos.

### Specifying the path to a parameters JSON file in `SimulationTemplate:update()`

If you were using the `params_json_path` parameter in [`SimulationTemplate:update()`](#luminarycloud.SimulationTemplate.update),
you should now pass the path to the JSON file as the `parameters` parameter instead.
