# v0.10.1

Release date: 2025-02-14

```{include} ../early-access.md
```

## Release Notes

This release has no breaking changes, but customers must update to this release
to remain compatible with the underlying API. Specifically, old SDK versions
will only get the first 50 projects with `lc.list_projects()`.

We recommend all customers upgrade to this release.

### Breaking Changes

None.

### Features

- [`Simulation`](#luminarycloud.Simulation) now includes `project_id`.
- EXPERIMENTAL: [`set_surface_deformation()`](#luminarycloud.Project.set_surface_deformation) method added to [`Project`](#luminarycloud.Project).
  - This is an experimental feature which may be changed or removed without notice.
- [`project()`](#luminarycloud.Geometry.project) method added to [`Geometry`](#luminarycloud.Geometry)
- [`select_volumes()`](#luminarycloud.Geometry.select_volumes) method added to [`Geometry`](#luminarycloud.Geometry)
- [`add_farfield()`](#luminarycloud.Geometry.add_farfield) method added to [`Geometry`](#luminarycloud.Geometry)
- [`iterate_projects()`](#luminarycloud.iterate_projects) method added to `luminarycloud`.
  - `iterate_projects()` returns an iterator that lazily loads projects from the server.  It should be preferred over `list_projects()`, which is now deprecated. 

### Deprecations

- [`list_projects()`](#luminarycloud.list_projects) is deprecated. Use [`iterate_projects()`](#luminarycloud.iterate_projects) instead.

### Bug Fixes / Improvements

- Reading and re-writing simulation params could erroneously modify certain list-type values, including boundary conditions and frame transforms. This is now fixed.

## Migration Guide

Anywhere you're using `list_projects()` to just iterate over the results one time, use `iterate_projects()` instead.

```py3
>>> for p in lc.iterate_projects():
...   print(f'{p.name}: {p.description}')
```

If you need a list of your projects, you can use a list comprehension or wrap the full result in a list.

```py3
>>> large_projects = [p for p in lc.iterate_projects() if p.storage_usage_bytes > 100e6]
    [Project(...), Project(...)]
>>> all_projects = list(lc.iterate_projects())
    [Project(...), Project(...)]
```

