# v0.13.0

Release date: 2025-04-03

```{include} ../early-access.md
```

## Release Notes

This release has breaking changes. It also adds a bunch of features. You're gonna love it.

### Breaking Changes

- Output Nodes have been removed along with their associated methods on [`Project`](#luminarycloud.Project): `create_output_node`, `delete_output_node`, `get_output_node`, `list_output_nodes`, and `update_output_node`.  They are replaced by Output Definitions, which are associated with a [`SimulationTemplate`](#luminarycloud.SimulationTemplate) rather than a [`Project`](#luminarycloud.Project).  See the Migration Guide for details.

### Features

- [`SimulationTemplate`](#luminarycloud.SimulationTemplate) now lets you define outputs. The new
methods are
[`list_output_definitions()`](#luminarycloud.SimulationTemplate.list_output_definitions()),
[`get_output_definition()`](#luminarycloud.SimulationTemplate.get_output_definition()),
[`create_output_definition()`](#luminarycloud.SimulationTemplate.create_output_definition()),
[`update_output_definition()`](#luminarycloud.SimulationTemplate.update_output_definition()), and
[`delete_output_definition()`](#luminarycloud.SimulationTemplate.delete_output_definition()), and
the classes they deal with are named like `outputs.*OutputDefinition`.
- [`SimulationTemplate`](#luminarycloud.SimulationTemplate) also lets you set stopping conditions on
those outputs. The new methods for that are
[`create_or_update_stopping_condition()`](#luminarycloud.SimulationTemplate.create_or_update_stopping_condition()),
[`list_stopping_conditions()`](#luminarycloud.SimulationTemplate.list_stopping_conditions()),
[`get_stopping_condition()`](#luminarycloud.SimulationTemplate.get_stopping_condition()), and
[`delete_stopping_condition()`](#luminarycloud.SimulationTemplate.delete_stopping_condition()). You
can also fetch and update general stopping conditions (e.g. max iterations) with
[`get_general_stopping_conditions()`](#luminarycloud.SimulationTemplate.get_general_stopping_conditions()) and
[`update_general_stopping_conditions()`](#luminarycloud.SimulationTemplate.update_general_stopping_conditions()).
- [`Project.create_geometry()`](#luminarycloud.Project.create_geometry) now allows converting continuous CAD into a discrete geometry by setting `convert_to_discrete` to `True`. This allows using the [`shrinkwrap`](#luminarycloud.VolumeSelection.shrinkwrap) operation to create a watertight representation of the geometry.
- [`SimulationParam`](#luminarycloud.SimulationParam) now has a [`to_code()`](#luminarycloud.SimulationParam.to_code) method which returns the Python code (as a string) that creates the identical object.
- [`vis.Threshold`](#luminarycloud.vis.Threshold) visualization filter has been added.
- [`Mesh`](#luminarycloud.Mesh) has a [`project_id`](#luminarycloud.Mesh.project) property and [`project()`](#luminarycloud.Mesh.project) method to get the [`Project`](#luminarycloud.Project) it belongs to.
- [`Solution`](#luminarycloud.Solution) now has a [`simulation()`](#luminarycloud.Solution.simulation) method to get the parent [`Simulation`](#luminarycloud.Simulation).
- [`Geometry`](#luminarycloud.Geometry) now has an [`update_tag()`](#luminarycloud.Geometry.update_tag) method.

### Deprecations

None.

### Bug Fixes / Improvements

- Some floats that had an empty serialized representation were causing errors on deserialization.
This was a rare thing, but it's fixed now.

## Migration Guide

### From OutputNodes to OutputDefinitions

If you were using Output Nodes before to set outputs on a Project, those were getting reflected in
the Setup tab of the UI, but by themselves they had no impact on Simulations.  If you want to
continue to use the SDK to define outputs that you see in the UI, you can set Output Definitions on
a Project's initial/default Simulation Template.  This template is automatically created for a
Project, and is named "Setup" by default.  Assuming you only have the default Simulation Template in
your project, you can replace this:

```py
my_project.create_output_node(...)
```

With this:

```py
sim_template = my_project.list_simulation_templates()[0]
sim_template.create_output_definition(...)
```

Note that if you're using multiple simulation templates in a project, the 0th one is not guaranteed
to be the default one.
