# v0.2.0

Release date: 2023-09-26

```{include} ../early-access.md
```

## Download

**[luminarycloud-0.2.0-py3-none-any.whl](https://storage.googleapis.com/luminarycloud-learning/sample-projects/lc-sdk/api-files/luminarycloud-0.2.0-py3-none-any.whl)**

See the [Upgrade Guide](./index.md#upgrade-guide) for instructions on how to upgrade a previously
installed SDK version.

## Release Notes

### Features

- Some classes and methods have been renamed.

  - `enum.SurfaceQuantityType` is now
  [`enum.QuantityType`](#luminarycloud.enum.quantity_type.QuantityType).

  - `Simulation.download_surface_quantity()` is now
  [`Simulation.download_surface_output()`](#luminarycloud.simulation.Simulation.download_surface_output).

  - `Simulation.download_surface_data()` is now
  [`Simulation.download_surface_solution()`](#luminarycloud.simulation.Simulation.download_surface_solution).

- [`Simulation.download_global_residuals()`](#luminarycloud.simulation.Simulation.download_global_residuals)

  - can now be used to fetch residuals for the latest iteration of each time
  step in transient flow simulations

  - the downloaded CSV  now contains the values for every available residual
  type, removing the need to request specific residual types.

  - more residual types are available, including residuals for turbulent kinetic
  energy (TKE), turbulence intermittency (gamma), momentum-thickness reynolds
  number (theta), specific dissipation rate (omega), and Spalart-Allmaras
  variable (SA).

- [`Simulation.download_surface_output()`](#luminarycloud.simulation.Simulation.download_surface_output)

  - can now be used to fetch surface outputs for the latest iteration of each
  time step in transient flow simulations

  - more output types are available, see
  [`enum.QuantityType`](#luminarycloud.enum.quantity_type.QuantityType)

  - more output parameters are available, including `force_direction`,
  `moment_center`, and `averaging type`. Some of these parameters are required
  to be set for the new output types.

  - added support for calculating a single aggregate output for a set of
  surfaces via the optional `calculation_type` parameter.

- [`Simulation.download_surface_solution()`](#luminarycloud.simulation.Simulation.download_surface_solution)

  - can now be used to download the surface solution of a transient flow
  simulation at a specific time step

### Bug Fixes

- No bug fixes in this SDK release.

## Migration Guide

The following code changes need to be applied to any existing code using the
SDK.

- Rename `enum.SurfaceQuantityType` to `enum.QuantityType`.

- Rename `Simulation:download_surface_quantity()` to
`download_surface_output()`.

- Rename `Simulation.download_surface_data()` to `download_surface_solution()`.

- Remove all imports of `enum.ResidualType` (no longer exists).

- Remove all existing parameters of `Simulation.download_global_residuals()`,
i.e. remove list of residual types from parameters, and add
`all_iterations=True` to parameters to have the same results as previous SDK
versions.

- The index column “Iteration” of the CSV downloaded via
`Simulation.download_global_residuals()` has been replaced by a new set of
columns: `Time step`, `Iteration index`, and `Physical time`. If your code parses and
uses the `Iteration` column, please update appropriately.