# v0.6.0

Release date: 2024-07-30

```{include} ../early-access.md
```

## Download

**[luminarycloud-0.6.0-py3-none-any.whl](https://storage.googleapis.com/luminarycloud-learning/sample-projects/lc-sdk/api-files/luminarycloud-0.6.0-py3-none-any.whl)**

See the [Upgrade Guide](./index.md#upgrade-guide) for instructions on how to upgrade a previously
installed SDK version.

## Release Notes

### Features

- A new [`Solution`](#luminarycloud.solution.Solution) class has been added.
Members of this class represent solutions at any completed iteration of a simulation.
- The [`Simulation.list_solutions()`](#luminarycloud.simulation.Simulation.list_solutions)
method has been added to the [`Simulation`](#luminarycloud.simulation.Simulation)
class.
- The `download_surface_solution()` and `download_volume_solution()` methods
have been removed from the [`Simulation`](#luminarycloud.simulation.Simulation)
class in favor of the [`download_surface_data()`](#luminarycloud.solution.Solution.download_surface_data)
and [`download_volume_data()`](#luminarycloud.solution.Solution.download_volume_data)
methods of the [`Solution`](#luminarycloud.solution.Solution) class.
- A new [`ReferenceValues`](#luminarycloud.reference_values.ReferenceValues)
class has been added. Instances of this class can be passed to the
[`Simulation.download_surface_output`](#luminarycloud.simulation.Simulation.download_surface_output)
method to define reference values used for computing forces, moments and other
non-dimensional output quantities.
- The `all_iterations` parameters has been removed from the
[`Simulation.download_surface_output`](#luminarycloud.simulation.Simulation.download_surface_output)
and [`Simulation.download_global_residuals`](#luminarycloud.simulation.Simulation.download_global_residuals)
methods. These methods will now always return results for all iterations.

## Migration Guide

### `download_surface_data` and `download_volume_data`

Upgrading to this SDK version will require replacing any calls to
[`download_surface_data()`](#luminarycloud.solution.Solution.download_surface_data)
or [`download_volume_data()`](#luminarycloud.solution.Solution.download_volume_data)
with the corresponding methods in the [`Solution`](#luminarycloud.solution.Solution)
class.

For example, suppose you have some code that downloads a surface solution:
```python
with simulation.download_surface_solution() as streaming_tar_file:
    ...
```
This downloads the surface data for the final solution for a completed
simulation.

To upgrade while maintaining the same behavior, you will need to first make a
call to [`list_solutions()`](#luminarycloud.simulation.Simulation.list_solutions)
to get the list of available solutions. For a completed simulation, the last
solution in this list should be the final solution. You can call
[`download_surface_data()`](#luminarycloud.solution.Solution.download_surface_data)
on it to download the surface data.

The migrated code should look something like this:
```python
latest_solution = simulation.list_solutions()[-1]
with latest_solution.download_surface_data() as streaming_tar_file:
    ...
```

## Specifying `reference_values`

You will need to update relevant uses of the
[`Simulation.download_surface_output`](#luminarycloud.simulation.Simulation.download_surface_output)
method to provide the new `reference_values` parameter. If this parameter is
not specified, default reference values will be used and could result in
unexpected outputs.

## Removing the `all_iterations` parameter

You will need to remove any instances of setting the `all_iterations` parameter in the
[`Simulation.download_surface_output`](#luminarycloud.simulation.Simulation.download_surface_output)
and [`Simulation.download_global_residuals`](#luminarycloud.simulation.Simulation.download_global_residuals)
methods.

Both of these methods will now return all iterations for steady state simulations.
If you had previously been calling either of these functions with `all_iterations`
unset or set to `False`, then you will need to drop all but the last row to
maintain the same behavior in your code.
